Catalog

Struct Catalog 

pub struct Catalog {
    pub video: Video,
    pub audio: Audio,
    pub user: Option<User>,
    pub chat: Option<Chat>,
    pub preview: Option<Track>,
}
A catalog track, created by a broadcaster to describe the tracks available in a broadcast.

Fields

video: Video

Video track information with multiple renditions.

Contains a map of video track renditions that the viewer can choose from based on their preferences (resolution, bitrate, codec, etc).

audio: Audio

Audio track information with multiple renditions.

Contains a map of audio track renditions that the viewer can choose from based on their preferences (codec, bitrate, language, etc).

user: Option<User>

User metadata for the broadcaster

chat: Option<Chat>

Chat track metadata

preview: Option<Track>

Preview information about the broadcast

Implementations

Source

impl Catalog

pub const DEFAULT_NAME: &str = "catalog.json"

The default name for the catalog track.

pub fn from_str(s: &str) -> Result<Self>

Parse a catalog from a string.

pub fn from_slice(v: &[u8]) -> Result<Self>

Parse a catalog from a slice of bytes.

pub fn from_reader(reader: impl Read) -> Result<Self>

Parse a catalog from a reader.

pub fn to_string(&self) -> Result<String>

Serialize the catalog to a string.

pub fn to_string_pretty(&self) -> Result<String>

Serialize the catalog to a pretty string.

pub fn to_vec(&self) -> Result<Vec<u8>>

Serialize the catalog to a vector of bytes.

pub fn to_writer(&self, writer: impl Write) -> Result<()>

Serialize the catalog to a writer.

pub fn default_track() -> Track